@@ -5,26 +5,31 @@
 # aendert in diesem script das laenderspezifische kuerzel
 # und fuehrt dieses script aus
 
+OLD="de"
+NEW="pt"
+
 for i in *html
 do
-	sed s/".html"/"_en.html"/g $i > $i.p
+	sed s/"$OLD"".html"/"$NEW"".html"/g $i > $i.p
 	mv $i.p $i
 done
 
 #sed veraendert auch <html> und </html> :-(
 for i in *html
 do
-	sed s/"<_en.html>"/"<\/html>"/g $i > $i.p
+	sed s/"<_""$NEW"".html>"/"<\/html>"/g $i > $i.p
 	mv $i.p $i
 done
 for i in *html
 do
-	sed s/"_en.html>"/"<html>"/g $i > $i.p
+	sed s/"_""$NEW"".html>"/"<html>"/g $i > $i.p
 	mv $i.p $i
 done
 
 
 for i in *.html; 
 do 
-	mv "$i" "${i%%.*}""_en.html"
+	#"Alles vor dem 1. Muster bleibt erhalten"
+	mv "$i" "${i%%_*}""_""$NEW"".html"
 done
+
