@@ -36,7 +36,7 @@ public class FractionMaker{
 	 * @param max
 	 */
 	public FractionMaker(int max){
-		makeZweiBrueche(max);
+		mkTwoFractions(max);
 	}
 	
 	/**
@@ -56,21 +56,30 @@ public class FractionMaker{
 	/**
 	 * macht einen unechten bruch kleiner als max
 	 */
-	public void makeUnechtenBruch(){
+	public void mkImproperFraction(){
 		int max = 7;
-		for (int pp = 0; pp < 10; pp++){
-		do{
-			numerator_1 = (Math.abs(JFractionLab.ran.nextInt())%80)+1;
-			denominator_1 = (Math.abs(JFractionLab.ran.nextInt())%10)+1;
-		}while ((numerator_1 <= denominator_1) || (numerator_1/denominator_1>max));
-		}
+//		for (int pp = 0; pp < 10; pp++){
+			do{
+				numerator_1 = (Math.abs(JFractionLab.ran.nextInt())%80)+1;
+				denominator_1 = (Math.abs(JFractionLab.ran.nextInt())%10)+1;
+			}while ((numerator_1 <= denominator_1) || (numerator_1/denominator_1>max));
+//		}
+	}
+	
+	public void mkImproperFraction(int max){
+//		for (int pp = 0; pp < 10; pp++){
+			do{
+				numerator_1 = (Math.abs(JFractionLab.ran.nextInt())%max)+1;
+				denominator_1 = (Math.abs(JFractionLab.ran.nextInt())%max)+1;
+			}while ((numerator_1 <= denominator_1));
+//		}
 	}
 	
 	/**
 	 * 
 	 * @param max
 	 */
-	public void makeZweiBrueche(int max){
+	public void mkTwoFractions(int max){
 		do{
 			numerator_1 = (Math.abs(JFractionLab.ran.nextInt())%max)+1;
 			//r.nextInt() creates a rindom number (int)
@@ -89,18 +98,24 @@ public class FractionMaker{
 	 * // optionen speicherbar machen (kuerzen, eigene aufgaben)
 	 * @param max
 	 */
-	public void makeEinenBruch(int max){
+	public void mkOneFraction(int max){
 		do{
 			numerator_1 = (Math.abs(JFractionLab.ran.nextInt())%max)+1;
 			denominator_1 = (Math.abs(JFractionLab.ran.nextInt())%max)+1;
 		}while (numerator_1 >= denominator_1);
 	}
 	
+	public void mkOneReducedFraction(int max){
+		do{
+			mkOneFraction(max);
+		}while (JFractionLab.greatestCommonDivisor(numerator_1, denominator_1)!=1);
+	}
+	
 	/**
 	 * 
 	 * @param max
 	 */
-	public void equalNumerators(int max){ //gleiche Zaehler
+	public void mkTwoFractionsWithEqualNumerators(int max){ //gleiche Zaehler
 		//makes two fractions with equal numerators
 		do{
 			numerator_1 = (Math.abs(JFractionLab.ran.nextInt())%max)+1;
@@ -118,7 +133,7 @@ public class FractionMaker{
 	 * 
 	 * @param max
 	 */
-	public void equalDenominators(int max){ //gleiche Nenner
+	public void mkTwoFractionsWithEqualDenominators(int max){ //gleiche Nenner
 		//makes two fractions with equal denominators
 		do{
 			numerator_1 = (Math.abs(JFractionLab.ran.nextInt())%max)+1;
@@ -132,6 +147,35 @@ public class FractionMaker{
 		//);
 	}
 	
+	public void mkDecimalFraction(){
+		int[] x = {2, 4, 5, 10, 20, 25, 50};
+		int ran = (Math.abs(JFractionLab.ran.nextInt())%7);
+		denominator_1 = x[ran];
+		if(denominator_1 == 2){
+			numerator_1 = 1;
+		}else if(denominator_1 == 4){
+			do{
+				//0<numerator_1<4
+				numerator_1 = (Math.abs(JFractionLab.ran.nextInt())%3+1);
+			}while(numerator_1 >= denominator_1);
+		}else if(denominator_1 == 5){
+			do{
+				//0<numerator_1<5
+				numerator_1 = (Math.abs(JFractionLab.ran.nextInt())%4+1);
+			}while(numerator_1 >= denominator_1);
+		}else if(denominator_1 == 10){
+			do{
+				//0<numerator_1<10
+				numerator_1 = (Math.abs(JFractionLab.ran.nextInt())%10+1);
+			}while(numerator_1 >= denominator_1);
+		}else{
+			do{
+				//0<numerator_1<49
+				numerator_1 = (Math.abs(JFractionLab.ran.nextInt())%49+1);
+			}while(numerator_1 >= denominator_1);
+		}
+	}
+	
 	/**
 	 * 
 	 * @param numerator
@@ -168,7 +212,7 @@ public class FractionMaker{
 	 * 
 	 * @return
 	 */
-	public int getZaehler_1(){
+	public int getNumerator_1(){
 		return(numerator_1);
 	}
 	
@@ -176,7 +220,7 @@ public class FractionMaker{
 	 * 
 	 * @return
 	 */
-	public int getZaehler_2(){
+	public int getNumerator_2(){
 		return(numerator_2);
 	}
 	
@@ -184,7 +228,7 @@ public class FractionMaker{
 	 * 
 	 * @return
 	 */
-	public int getNenner_1(){
+	public int getDenominator_1(){
 		return(denominator_1);
 	}
 	
@@ -192,7 +236,7 @@ public class FractionMaker{
 	 * 
 	 * @return
 	 */
-	public int getNenner_2(){
+	public int getDenominator_2(){
 		return(denominator_2);
 	}
 }//class
\ No newline at end of file
