@@ -33,6 +33,7 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.ObjectInputStream;
 import java.util.Locale;
+
 import java.util.Random;
 
 import javax.swing.JButton;
@@ -50,6 +51,7 @@ import javax.swing.border.EmptyBorder;
 import javax.swing.border.EtchedBorder;
 import javax.swing.border.TitledBorder;
 
+
 import jfractionlab.displays.PointDisplay;
 import jfractionlab.exerciseDialogs.ClickNumerator;
 import jfractionlab.exerciseDialogs.CompareFractions;
@@ -64,37 +66,44 @@ import jfractionlab.exerciseDialogs.MultiplyFractions;
 import jfractionlab.exerciseDialogs.NameFraction;
 import jfractionlab.exerciseDialogs.PlusAndMinus;
 import jfractionlab.exerciseDialogs.ReduceFraction;
-import jfractionlab.jflDialogs.ConfigurePDFLATEXDialog;
+import jfractionlab.exerciseGenerator.ExerciseGenerator;
+import jfractionlab.jflDialogs.ConfigureLO;
 import jfractionlab.jflDialogs.InfoDialog;
 import jfractionlab.jflDialogs.LogSaverDialog;
-import jfractionlab.jflDialogs.WorkSheetDialogAddition;
-import jfractionlab.jflDialogs.WorkSheetDialogDivision;
-import jfractionlab.jflDialogs.WorkSheetDialogExtending;
-import jfractionlab.jflDialogs.WorkSheetDialogImproperFractions;
-import jfractionlab.jflDialogs.WorkSheetDialogMixedNumbers;
-import jfractionlab.jflDialogs.WorkSheetDialogMultiplication;
-import jfractionlab.jflDialogs.WorkSheetDialogReducing;
-import jfractionlab.jflDialogs.WorkSheetDialogSubtraction;
+import jfractionlab.jflDialogs.WorkSheetDialog;
 import jfractionlab.logtable.LogTable;
 
-//TODO jfractionlab.JFractionLab
-//help chapter fraction to decimal
-//help chapter how to make worksheets
 
 
-//windows: confFile schreiben (class properties?)-> pfad zu pdflatex in conffile schreiben -> worksheetgenerator winpdflatex aktivieren
+//TODO JFractionLab
+
+//begriffe fuer aufgaben (zettel) und übungen (am computer)
 
 //neuer aufgabentyp: vergleichen durch gleichnamig machen?
+//Link zur Hilfe (oder mindestens hineis auf hilfekapitel) in fehlermeldung "kein LO-Kontakt"
 
-//worksheets und worksheet-dialogs aufraeumen - besseres design
-//worksheets als odt
+//Hilfe: ****************************
+//configureLO_de.html url einsetzen
+//CompareFractions: hilfe schreiben und implementieren
+//FractionToDecimal Hilfekapitel schreiben und hier verlinken!
+//hilfe besser internationalisieren mit cmssimple?? "offline"-cms ohne datenbank??
 
+//Worksheets: ***********************
+//FractionToDecimal ADD WORKSHEET
+//arbeitsblätter mit verschiedenen aufgabentypen ermoeglichen, dialog mit allen auswahlmöglichkeiten schreiben
+
+//Release: ******************************
+//testen (achte auf ConfigureLO unter windows!!)
+//uebersetzen
+//pakete machen
 //document the code with javadoc
 
 public class JFractionLab extends JFrame implements ActionListener, ItemListener{
 	public static final long serialVersionUID = 54L;
 	public static final String jep_fontface="<font face='Avalon,Wide Latin'>";
 	public static final Random ran = new Random(System.currentTimeMillis());
+	public static final int nbOfUnoConfJars = 7;
+	public static boolean worksheetProcessIsOK = true;
 	private JMenuBar jmb = new JMenuBar();
 	private JMenu jmLanguage = new JMenu("");
 		private JMenuItem jmiGerman = new JMenuItem("");
@@ -113,9 +122,9 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		private JMenuItem jmiWorkSheetSubtraction = new JMenuItem("");
 		private JMenuItem jmiWorkSheetMultiplication = new JMenuItem("");
 		private JMenuItem jmiWorkSheetDivision = new JMenuItem("");
-		private JMenuItem jmiConfigurePDFLatex;
+		private JMenuItem jmiConfigurePathToLibreOffice;
 	private JMenu jmHelp = new JMenu("");
-	private static JCheckBoxMenuItem cb_showtippatstart = new JCheckBoxMenuItem();
+	public static JCheckBoxMenuItem cb_showtippatstart = new JCheckBoxMenuItem();
 	private JMenuItem jmiAbout = new JMenuItem("");
 	private JMenuItem jmiHelp = new JMenuItem("");
 	//GUI
@@ -194,17 +203,16 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		});//invokeLater
 	}
 	
-	/**
-	 * 
-	 * @throws HeadlessException
-	 */
 	public JFractionLab() throws HeadlessException {
+		makeGUI();
+	}
+	
+	public void makeGUI(){
 		os = System.getProperty("os.name").toLowerCase();
 		setTitle("JFractionLab_version-number_lab");
 		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
 
 		lang.Messages.setLocale(lang.Messages.getLocale());
-		
 		//Menue
 		jmLanguage.setText(lang.Messages.getString("language"));
 		
@@ -237,7 +245,6 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		jmLanguage.add(jmiPortuguese);
 		
 		jmWorkSheet.setText(lang.Messages.getString("worksheets"));
-
 		
 		jmiWorkSheetExtending.addActionListener(this);
 		jmiWorkSheetExtending.setText(lang.Messages.getString("extend_fractions"));
@@ -271,20 +278,17 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		jmiWorkSheetDivision.setText(lang.Messages.getString("div_fr_by_fr"));
 		jmWorkSheet.add(jmiWorkSheetDivision);
 
-		if(os.contains("win")){
-			jmWorkSheet.addSeparator();
-			jmiConfigurePDFLatex = new JMenuItem();
-			jmiConfigurePDFLatex.addActionListener(this);
-			jmiConfigurePDFLatex.setText(lang.Messages.getString("configure_pdflatex"));
-			jmWorkSheet.add(jmiConfigurePDFLatex);
-		}
+		jmWorkSheet.addSeparator();
+		jmiConfigurePathToLibreOffice = new JMenuItem();
+		jmiConfigurePathToLibreOffice.addActionListener(this);
+		jmiConfigurePathToLibreOffice.setText(lang.Messages.getString("configure_libreoffice"));
+		jmWorkSheet.add(jmiConfigurePathToLibreOffice);
 		
 		jmHelp.setText(lang.Messages.getString("jmi_help"));
 		
 		cb_showtippatstart.setText(lang.Messages.getString("show_hints_on_start"));
-		
-		setCheckBoxValue();
 		cb_showtippatstart.addItemListener(this);
+		setCheckBoxValue();
 		jmHelp.add(cb_showtippatstart);
 		
 		jmHelp.addSeparator();
@@ -422,15 +426,15 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		//JFrame.setDefaultLookAndFeelDecorated(true);
 		try{
 			UIManager.setLookAndFeel("javax.swing.plaf.metal.MetalLookAndFeel");
+			//UIManager.setLookAndFeel("javax.swing.plaf.metal.NimbusLookAndFeel");
 			//UIManager.setLookAndFeel("com.sun.java.swing.plaf.motif.MotifLookAndFeel");
 			//UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");
 			//UIManager.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
 			//UIManager.setLookAndFeel( UIManager.getSystemLookAndFeelClassName() );
 		}catch(Exception exc){
 			exc.printStackTrace();
-			//System.out.println("UIManager Problem");
+			System.out.println("UIManager Problem");
 		}
-		//setMainWindowPointDisplaysForDemoReason();
 		setVisible(true);
 
 		aboutText =
@@ -460,7 +464,8 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 			+"Daniel Barbalace, https://tablelayout.dev.java.net/</li></ul>"
 		;//String
 		
-	}//constructor
+		
+	}//makeGUI
 	
 	/**
 	 * 
@@ -538,9 +543,8 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		jmiWorkSheetSubtraction.setText(lang.Messages.getString("minus_fractions"));
 		jmiWorkSheetMultiplication.setText(lang.Messages.getString("multiply_fractions"));
 		jmiWorkSheetDivision.setText(lang.Messages.getString("div_fr_by_fr"));
-		if(os.contains("win")){
-			jmiConfigurePDFLatex.setText(lang.Messages.getString("configure_pdflatex"));
-		}
+		jmiConfigurePathToLibreOffice.setText(lang.Messages.getString("configure_libreoffice"));
+
 		jmHelp.setText(lang.Messages.getString("Info"));
 		jmiHelp.setText(lang.Messages.getString("jmi_help"));
 		cb_showtippatstart.setText(lang.Messages.getString("show_hints_on_start"));
@@ -569,11 +573,13 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 	}//refreshCaption
 	
 	public static void setCheckBoxValue(){
-		if(new ConfManager().isTipAtStart()){
+		ConfManager cm = new ConfManager();
+		if(cm.isTipAtStart()){
 			cb_showtippatstart.setSelected(true);
 		}else{
 			cb_showtippatstart.setSelected(false);
 		}
+		
 	}
 	
 	public void itemStateChanged(ItemEvent e){
@@ -810,23 +816,50 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 //			refreshCaption();
 //		}
 		else if(obj == jmiWorkSheetExtending){
-			new WorkSheetDialogExtending();
+			new WorkSheetDialog(
+					ExerciseGenerator.EXTEND_FRACTIONS,
+					lang.Messages.getString("extend_fractions"),
+					lang.Messages.getString("fractions"),
+					lang.Messages.getString("factors")
+			);
 		}else if(obj == jmiWorkSheetReducing){
-			new WorkSheetDialogReducing();
+			new WorkSheetDialog(
+					ExerciseGenerator.REDUCE_FRACTIONS,
+					lang.Messages.getString("reduce_fractions"),
+					lang.Messages.getString("fractions"),
+					lang.Messages.getString("factors")
+			);
 		}else if(obj == jmiWorkSheetImproperFractions){
-			new WorkSheetDialogImproperFractions();
+			new WorkSheetDialog(
+					ExerciseGenerator.IMPROPER_FRACTIONS,
+					lang.Messages.getString("improper_fracs"),
+					lang.Messages.getString("fractions")
+			);
 		}else if(obj == jmiWorkSheetMixedNumbers){
-			new WorkSheetDialogMixedNumbers();
+			new WorkSheetDialog(
+					ExerciseGenerator.MIXED_NUMBERS,
+					lang.Messages.getString("mixed_numbers"),
+					lang.Messages.getString("full_numbers"),
+					lang.Messages.getString("fractions")
+			);
 		}else if(obj == jmiWorkSheetAddition){
-			new WorkSheetDialogAddition();
+			new WorkSheetDialog(ExerciseGenerator.ADD_FRACTIONS, lang.Messages.getString("add_fractions"));
 		}else if(obj == jmiWorkSheetSubtraction){
-			new WorkSheetDialogSubtraction();
+			new WorkSheetDialog(ExerciseGenerator.SUBTRACT_FRACTIONS, lang.Messages.getString("minus_fractions"));
 		}else if(obj == jmiWorkSheetMultiplication){
-			new WorkSheetDialogMultiplication();
+			new WorkSheetDialog(
+					ExerciseGenerator.MULTIPLY_FRACTIONS,
+					lang.Messages.getString("multiply_fractions"),
+					lang.Messages.getString("fractions")
+			);
 		}else if(obj == jmiWorkSheetDivision){
-			new WorkSheetDialogDivision();
-		}else if (obj == jmiConfigurePDFLatex){
-			new ConfigurePDFLATEXDialog();
+			new WorkSheetDialog(
+					ExerciseGenerator.DIVIDE_FRACTIONS,
+					lang.Messages.getString("div_fr_by_fr"),
+					lang.Messages.getString("fractions")
+			);
+		}else if (obj == jmiConfigurePathToLibreOffice){
+			new ConfigureLO();
 		}
 		else if (obj == jmiHelp){
 			new HelpStarter(
@@ -848,6 +881,4 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		// verwendet wird der Satz ggT(a,b) * kgV(a,b) = a*b
 		return (a*b)/greatestCommonDivisor(a,b);
 	}
-	
-	
 }//class
