@@ -31,15 +31,17 @@ import java.awt.event.KeyListener;
 import javax.swing.JButton;
 import javax.swing.JLabel;
 
-import jfractionlab.ConfManager;
 import jfractionlab.FractionMaker;
 import jfractionlab.HelpStarter;
 import jfractionlab.JFractionLab;
 import jfractionlab.MyJTextField;
 import jfractionlab.displays.FractionAsCircle;
 import jfractionlab.displays.FractionLine;
+import jfractionlab.exerciseGenerator.ExerciseGenerator;
 import jfractionlab.jflDialogs.UsabilityDialog;
-import jfractionlab.jflDialogs.WorkSheetDialogMixedNumbers;
+import jfractionlab.jflDialogs.WorkSheetDialog;
+
+
 
 
 
@@ -340,7 +342,12 @@ public class MixedNumbers extends ExerciseDialog implements ActionListener, KeyL
 				tf_improperFractionDenominator.setText("");
 				nextProblem();
 			}else if(obj == jmiCreateWorkSheet){
-				new WorkSheetDialogMixedNumbers();
+				new WorkSheetDialog(
+						ExerciseGenerator.MIXED_NUMBERS,
+						lang.Messages.getString("mixed_numbers"),
+						lang.Messages.getString("full_numbers"),
+						lang.Messages.getString("fractions")
+				);
 			}else if(obj == jmiHelp){
 				new HelpStarter(
 						lang.Messages.getLocale().toString(),
