@@ -36,10 +36,12 @@ import jfractionlab.JFractionLab;
 import jfractionlab.MyJTextField;
 import jfractionlab.displays.FractionAsRectangle;
 import jfractionlab.displays.FractionLine;
+import jfractionlab.exerciseGenerator.ExerciseGenerator;
 import jfractionlab.jflDialogs.UsabilityDialog;
 import jfractionlab.jflDialogs.WannaReduceQuestion;
-import jfractionlab.jflDialogs.WorkSheetDialogMultiplication;
-import jfractionlab.worksheets.ExerciseMultDivision;
+import jfractionlab.jflDialogs.WorkSheetDialog;
+
+
 
 
 
@@ -426,7 +428,11 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 			smallNumbers = false;
 			nextProblem();
 		}else if(obj == jmiCreateWorkSheet){
-			new WorkSheetDialogMultiplication();
+			new WorkSheetDialog(
+					ExerciseGenerator.MULTIPLY_FRACTIONS,
+					lang.Messages.getString("multiply_fractions"),
+					lang.Messages.getString("fractions")
+			);
 		}else if(obj == jmiHelp){
 			new HelpStarter(
 					lang.Messages.getLocale().toString(),
