@@ -30,19 +30,18 @@ import java.awt.event.KeyListener;
 
 import javax.swing.JLabel;
 
-import jfractionlab.ConfManager;
 import jfractionlab.FractionMaker;
 import jfractionlab.HelpStarter;
 import jfractionlab.JFractionLab;
 import jfractionlab.MyJTextField;
 import jfractionlab.displays.FractionAsCircle;
 import jfractionlab.displays.FractionLine;
+import jfractionlab.exerciseGenerator.ExerciseGenerator;
 import jfractionlab.jflDialogs.UsabilityDialog;
 import jfractionlab.jflDialogs.WannaFindBestCommonDenominator;
 import jfractionlab.jflDialogs.WannaReduceQuestion;
-import jfractionlab.jflDialogs.WorkSheetDialogAddition;
-import jfractionlab.jflDialogs.WorkSheetDialogMultiplication;
-import jfractionlab.jflDialogs.WorkSheetDialogSubtraction;
+import jfractionlab.jflDialogs.WorkSheetDialog;
+
 
 
 public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyListener{
@@ -385,9 +384,9 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 		}
 		else if(obj == jmiCreateWorkSheet){
 			if(operator.equals("+")){
-				new WorkSheetDialogAddition();
+				new WorkSheetDialog(ExerciseGenerator.ADD_FRACTIONS, lang.Messages.getString("add_fractions"));
 			}else{
-				new WorkSheetDialogSubtraction();
+				new WorkSheetDialog(ExerciseGenerator.SUBTRACT_FRACTIONS, lang.Messages.getString("minus_fractions"));
 			}
 		}
 		else if(obj == jmiHelp){
